@@ -24,8 +24,9 @@
 #include <QPointer>
 #include <QVariantList>
 #include <PackageKit/Transaction>
+#include <functional>
 
-class QTimer;
+class QProcess;
 
 class PackageKitNotifier : public BackendNotifierModule
 {
@@ -53,6 +54,8 @@ private Q_SLOTS:
     void finished(PackageKit::Transaction::Exit exit, uint);
     
 private:
+    QProcess* checkAptVariable(const QString &aptconfig, const QLatin1String& varname, std::function<void(const QStringRef& val)> func);
+
     Update m_update;
     uint m_securityUpdates;
     uint m_normalUpdates;
