@@ -31,6 +31,7 @@ class AbstractResourcesBackend;
 class DISCOVERCOMMON_EXPORT StandardBackendUpdater : public AbstractBackendUpdater
 {
     Q_OBJECT
+    Q_PROPERTY(int updatesCount READ updatesCount NOTIFY updatesCountChanged)
     public:
         explicit StandardBackendUpdater(AbstractResourcesBackend* parent = nullptr);
 
@@ -46,14 +47,13 @@ class DISCOVERCOMMON_EXPORT StandardBackendUpdater : public AbstractBackendUpdat
         QDateTime lastUpdate() const override;
         bool isCancelable() const override;
         bool isProgressing() const override;
-        QString statusDetail() const override;
-        QString statusMessage() const override;
-        quint64 downloadSpeed() const override;
         bool isMarked(AbstractResource* res) const override;
-        void setStatusDetail(const QString& message);
         void setProgress(qreal p);
         int updatesCount() const;
 
+    Q_SIGNALS:
+        void updatesCountChanged(int updatesCount);
+
     public Q_SLOTS:
         void transactionRemoved(Transaction* t);
         void cleanup();
@@ -69,7 +69,6 @@ class DISCOVERCOMMON_EXPORT StandardBackendUpdater : public AbstractBackendUpdat
         AbstractResourcesBackend * const m_backend;
         QSet<AbstractResource*> m_pendingResources;
         bool m_settingUp;
-        QString m_statusDetail;
         qreal m_progress;
         QDateTime m_lastUpdate;
 };
